Class: Taurus::XML::Document::Freed Private

Inherits:
Struct
  • Object
show all
Defined in:
lib/taurus/xml/document.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Internal flag container shared between the Document instance and its GC finalizer. Using a one-element Array because Procs close over variables by reference — mutating freed is visible from both the explicit free path and the finalizer. This eliminates the double-free that FFI::AutoPointer's release proc caused when Document#free was called explicitly and then GC ran.

Instance Attribute Summary collapse

Instance Attribute Details

#stateObject

Returns the value of attribute state

Returns:

  • (Object)

    the current value of state



15
16
17
# File 'lib/taurus/xml/document.rb', line 15

def state
  @state
end